@@ -47,7 +47,7 @@ sql_call2 <- function(.fn, ..., con = sql_current_con()) {
 
 
 replace_expr <- function(x, con) {
-  if (is.atomic(x)) {
+  if (is.atomic(x) || is_blob(x)) {
     as.character(escape(unname(x), con = con))
   } else if (is.name(x)) {
     as.character(x)
@@ -77,3 +77,4 @@ replace_expr <- function(x, con) {
   }
 
 }
+
