@@ -1,3 +1,4 @@
+# nocov start
 .onLoad <- function(...) {
   register_s3_method("dplyr", "union", "tbl_lazy")
   register_s3_method("dplyr", "intersect", "tbl_lazy")
@@ -6,14 +7,25 @@
   register_s3_method("dplyr", "setdiff", "OraConnection")
   register_s3_method("dplyr", "filter", "tbl_lazy")
 
-  # These are also currently defined in dplyr, and we want to avoid a warning
-  # about double duplication. Conditional can be removed after update to
-  # dplyr
-  if (!methods::isClass("sql")) {
-    setOldClass(c("sql", "character"), sql())
+  if (utils::packageVersion("dplyr") >= "0.8.99") {
+    register_s3_method("dplyr", "group_by_drop_default", "tbl_lazy")
+
+    methods::setOldClass(c("ident_q", "ident", "character"), ident_q())
+    methods::setOldClass(c("ident", "character"), ident())
+    methods::setOldClass(c("sql", "character"), sql())
   }
 }
 
+# Silence R CMD check note:
+# ** checking whether the namespace can be loaded with stated dependencies ... NOTE
+# Warning in .undefineMethod("initialize", Class, classWhere) :
+#   no generic function 'initialize' found
+#
+# I'm not sure why this is necessary, but I suspect it's due to the use of
+# setOldClass onLoad
+#' @importFrom methods initialize
+NULL
+
 register_s3_method <- function(pkg, generic, class, fun = NULL) {
   stopifnot(is.character(pkg), length(pkg) == 1)
   stopifnot(is.character(generic), length(generic) == 1)
@@ -37,4 +49,4 @@ register_s3_method <- function(pkg, generic, class, fun = NULL) {
     }
   )
 }
-
+# nocov end
