@@ -8,10 +8,10 @@ test_that("use CHAR type for as.character", {
 })
 
 test_that("logicals converted to integer correctly", {
-  skip_if_no_db("mysql")
+  skip_if_no_db("MariaDB")
 
   df1 <- data.frame(x = c(TRUE, FALSE, NA))
-  df2 <- src_test("mysql") %>% copy_to(df1, unique_table_name()) %>% collect()
+  df2 <- src_test("MariaDB") %>% copy_to(df1, unique_table_name()) %>% collect()
 
   expect_identical(df2$x, c(1L, 0L, NA))
 })
