@@ -86,6 +86,15 @@ test_that("date and date-times are converted to ISO 8601", {
   expect_equal(escape(x2, con = con), sql("'2000-01-02'"))
 })
 
+# Raw -----------------------------------------------------------------
+
+test_that("raw is SQL-99 compatible (by default)", {
+  con <- simulate_dbi()
+  expect_equal(escape(as_blob(raw(0)), con = con), sql("X''"))
+  expect_equal(escape(as_blob(as.raw(c(0x01, 0x02, 0x03))), con = con), sql("X'010203'"))
+  expect_equal(escape(as_blob(as.raw(c(0x00, 0xff))), con = con), sql("X'00ff'"))
+})
+
 # names_to_as() -----------------------------------------------------------
 
 test_that("names_to_as() doesn't alias when ident name and value are identical", {
